Module error

Module error 

Structs

Offset
The number of characters since the begin of a source file.

Enums

SolverError

Functions

format_error
Show the error in the context of the relevant source code.