pub fn format_error(input: &str, e: SolverError) -> StringExpand description
Show the error in the context of the relevant source code.
pub fn format_error(input: &str, e: SolverError) -> StringShow the error in the context of the relevant source code.